pecos.qeccs.color\_488.instructions
===================================

.. automodule:: pecos.qeccs.color_488.instructions











   .. rubric:: Classes

   .. autosummary::

      InstrInitPlus
      InstrInitZero
      InstrSynExtraction
